==> haskell-deque-0.4.4.2-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.2
visibility:           public
id:                   deque-0.4.4.2-G55DoYRXaLf4sw4SO7CF8s
key:                  deque-0.4.4.2-G55DoYRXaLf4sw4SO7CF8s
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  47e4d9912f6d34d087599d7ff30bb6d2
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.2-G55DoYRXaLf4sw4SO7CF8s
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.5.0-46ofdJt9DgFJv5hpm4ccL9 mtl-2.2.2
    strict-list-0.1.7.6-KIKbPgHg936A0u79pGFPnr

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deque-0.4.4.2-89-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deque.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 deque
version:              0.4.4.2
visibility:           public
id:                   deque-0.4.4.2-wEMFKKbScdE0kGKgXrL3I
key:                  deque-0.4.4.2-wEMFKKbScdE0kGKgXrL3I
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/deque
synopsis:             Double-ended queues
description:
    Strict and lazy implementations of Double-Ended Queue (aka Dequeue or Deque)
    based on head-tail linked list.

category:             Data
abi:                  1af09f906f8650ff29eb114873166bf0
exposed:              True
exposed-modules:
    Deque.Lazy Deque.Lazy.Reader Deque.Lazy.State Deque.Strict
    Deque.Strict.Reader Deque.Strict.State

hidden-modules:       Deque.Lazy.Defs Deque.Prelude Deque.Strict.Defs
import-dirs:          /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/deque-0.4.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-deque
hs-libraries:         HSdeque-0.4.4.2-wEMFKKbScdE0kGKgXrL3I
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    hashable-1.4.6.0-2vEivDIcaMF9mfkC7wRjoU mtl-2.2.2
    strict-list-0.1.7.6-EQTuyxAyrk5Bw2wP3cdrb

haddock-interfaces:   /usr/share/doc/haskell-deque/html/deque.haddock
haddock-html:         /usr/share/doc/haskell-deque/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
